%if "%{?distro_section}" == "tainted"
%define include_patented_variants 1
%else
%define include_patented_variants 0
%endif

Name:           xboard
Version:        4.9.1
Release:        %mkrel 6
Summary:        An X Window System graphical chessboard
License:        GPLv3+
Group:          Games/Boards
URL:            https://www.gnu.org/software/xboard
Source0:        https://ftp.gnu.org/gnu/xboard/%{name}-%{version}.tar.gz
Source1:        https://ftp.gnu.org/gnu/xboard/%{name}-%{version}.tar.gz.sig
%if !%{include_patented_variants}
Patch1:         xboard-4.9.0-mga-remove-patented-chess-variants.patch
%endif
# (kamil) use universal xvt and not xterm for man and info help window
Patch2:         xboard-4.7.3-mga-replace-xterm-with-xvt.patch
Patch3:         xboard-4.9.1-mga-multiple-def.patch

BuildRequires:  texinfo
BuildRequires:	pkgconfig(cairo) >= 1.2.0
BuildRequires:	pkgconfig(librsvg-2.0) >= 2.14.0
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	gettext-devel
BuildRequires:	xdg-utils
Requires:       xorg-x11-fonts
# default chess engine
Recommends:       fairymax
# to play sounds
Recommends:       alsa-utils
# for UCI chess engines
Recommends:       polyglot

%description
XBoard is a graphical user interface for chess in all its major forms,
including international chess, xiangqi (Chinese chess), shogi (Japanese chess)
and Makruk, in addition to many minor variants such as Losers Chess,
Crazyhouse, Chess960 and Capabanca Chess. It displays a chessboard on the
screen, accepts moves made with the mouse, and loads and saves games in
Portable Game Notation (PGN). It serves as a front-end for many different chess
services, including:
- Chess engines that will run on your machine and play a game against you or
help you analyze, such as GNU Chess, Crafty, or many others.
- Chess servers on the Internet, where you can connect to play chess with
people from all over the world, watch other users play, or just hang out and
chat.
- Correspondence chess played by electronic mail. The CMail program automates
the tasks of parsing email from your opponent, playing his moves out on your
board, and mailing your reply move after you've chosen it.

XBoard runs on Unix and Unix-like systems that use the X Window System.

XBoard is built with zippy.

%if %include_patented_variants
Gothic Chess is protected by U.S. patent #6,481,716 by Ed Trice.
Falcon Chess is protected by U.S. patent #5,690,334 by George W. Duke
%endif


%prep
%autosetup -p1

%build
autoreconf -fi
%configure --bindir=%{_gamesbindir} --with-gtk
%make_build

%install
%make_install

install -m 0755 -p cmail %{buildroot}%{_gamesbindir}

%find_lang %{name}

%files -f %{name}.lang
%doc AUTHORS ChangeLog COPYING COPYRIGHT NEWS README SHORTLOG TODO zippy.README
%doc *.txt *.html
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_gamesbindir}/cmail
%{_gamesbindir}/%{name}
%{_gamesdatadir}/%{name}/
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_infodir}/%{name}.info*
%{_mandir}/man6/%{name}.6*
%config(noreplace) %{_sysconfdir}/%{name}.conf


%changelog
* Thu Aug 20 2020 ovitters <ovitters> 4.9.1-6.mga8
+ Revision: 1616884
- remove install-info scriptlets, rely on filetrigger instead (mga#27107)

* Wed Aug 05 2020 joequant <joequant> 4.9.1-5.mga8
+ Revision: 1611141
- update deps

* Fri May 15 2020 danf <danf> 4.9.1-4.mga8.tainted
+ Revision: 1583999
- Switch http: URLs to https:
- Fix multiple definition error with gcc 10.1

* Fri Feb 14 2020 umeabot <umeabot> 4.9.1-3.mga8.tainted
+ Revision: 1519165
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 4.9.1-2.mga7
+ Revision: 1301809
- Mageia 7 Mass Rebuild

* Sun Jan 29 2017 akien <akien> 4.9.1-1.mga6.tainted
+ Revision: 1084152
- Version 4.9.1

* Thu May 26 2016 akien <akien> 4.9.0-2.mga6.tainted
+ Revision: 1018649
- Rebuild for tainted/release (BS bug)

* Thu May 26 2016 akien <akien> 4.9.0-1.1.mga6
+ Revision: 1018645
- Rebuild for core/release (BS bug)

* Thu May 26 2016 akien <akien> 4.9.0-1.mga6.tainted
+ Revision: 1018640
- Rediff P1 removing patented chess variants
- Version 4.9.0

* Tue Feb 09 2016 umeabot <umeabot> 4.8.0-2.mga6.tainted
+ Revision: 950996
- Mageia 6 Mass Rebuild

* Sun Nov 30 2014 cjw <cjw> 4.8.0-1.mga5.tainted
+ Revision: 800033
- add BuildRequires: gettext-devel
- 4.8.0
- switch to GTK (fixes font problem, mga#13810)

* Wed Oct 15 2014 umeabot <umeabot> 4.7.3-4.mga5.tainted
+ Revision: 742285
- Second Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sat Aug 16 2014 akien <akien> 4.7.3-3.mga5.tainted
+ Revision: 663889
- Rediff and reapply Patch1 and Patch2

* Sat Feb 15 2014 dams <dams> 4.7.3-2.mga5.tainted
+ Revision: 592066
- new version 4.7.3

* Mon Oct 21 2013 umeabot <umeabot> 4.7.2-2.mga4.tainted
+ Revision: 536922
- Mageia 4 Mass Rebuild

* Wed Sep 25 2013 fwang <fwang> 4.7.2-1.mga4
+ Revision: 485882
- update file list
- update file list
- update file list
- update desktop file
- new version 4.7.2

* Mon Jan 14 2013 umeabot <umeabot> 4.6.2-5.mga3.tainted
+ Revision: 386635
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 4.6.2-4.mga3.tainted
+ Revision: 324892
- rebuild for Mga3 Beta1

* Wed Jul 25 2012 kamil <kamil> 4.6.2-3.mga3.tainted
+ Revision: 274361
- suggest polyglot - a chess engine protocol translator

* Mon May 28 2012 kamil <kamil> 4.6.2-2.mga3.tainted
+ Revision: 247734
- drop P0 from this package (again)

* Mon May 28 2012 kamil <kamil> 4.6.2-1.mga3.tainted
+ Revision: 247720
- new version 4.6.2
- rediff P1, P2
- drop P0, it's already announced in GUI and man

* Sat Mar 10 2012 kamil <kamil> 4.5.3-4.mga2.tainted
+ Revision: 222381
- add P2 -mga-replace-xterm-with-xvt.patch (use an universal terminal for man and info window invocation

* Mon Jan 09 2012 kamil <kamil> 4.5.3-3.mga2.tainted
+ Revision: 194245
- fix creation of symlink of the man-page of cmail
- rename patches to fit policies
- clean spec

* Fri Oct 14 2011 kamil <kamil> 4.5.3-2.mga2.tainted
+ Revision: 155273
- xboard suggests alsa-util to play sounds
- xboard requires xorg-x11-fonts (100dpi or 75dpi) instead of only 100dpi
- fairymax (a chess engine) and xterm (x terminal emulator) are now suggested

* Tue Oct 04 2011 kamil <kamil> 4.5.3-1.mga2.tainted
+ Revision: 151546
- New version 4.5.3

* Sat Sep 24 2011 obgr_seneca <obgr_seneca> 4.5.2a-1.mga2.tainted
+ Revision: 147370
- new version 4.5.2a
- now licensed under GPLv3+
- description updated
- requirements updated
- default chess engine updated - changed from GNU Chess (gnuchess) to Fairy-Max (fairymax)
- man page cmail.6* is symliked to the xboard.6* man page
- this package provides cmail
- disable all partly suported board sizes
- SPEC file provided by Kamil Rytarowski
- clean up

* Sun May 15 2011 pterjan <pterjan> 4.2.7-15.mga1
+ Revision: 99043
- Rebuild for fixed find-requires

* Wed Apr 27 2011 wally <wally> 4.2.7-14.mga1
+ Revision: 92042
- fix desktop file name (mga#954)
- drop buildroot definition
- fix exec line in desktop file

* Wed Mar 16 2011 steletch <steletch> 4.2.7-13.mga1
+ Revision: 72896
- Clean spec file
- imported package xboard

